@@ -1,6 +1,6 @@
 /*
  * This file is part of the Colobot: Gold Edition source code
- * Copyright (C) 2001-2020, Daniel Roux, EPSITEC SA & TerranovaTeam
+ * Copyright (C) 2001-2023, Daniel Roux, EPSITEC SA & TerranovaTeam
  * http://epsitec.ch; http://colobot.info; http://github.com/colobot
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 #include "CBot/CBotEnums.h"
 #include "CBot/CBotUtils.h"
 
+#include <cstdint>
 #include <string>
 
 namespace CBot
@@ -199,7 +200,7 @@ public:
      * \brief GetType Returns the base type of the variable (::CBotType)
      * \param mode Mode, see GetTypeMode enum
      */
-    CBotType GetType(GetTypeMode mode = GetTypeMode::NORMAL);
+    CBotType GetType(GetTypeMode mode = GetTypeMode::NORMAL) const;
 
     /**
      * \brief Returns the complete type of the variable (CBotTypResult)
@@ -243,7 +244,6 @@ public:
         UNDEF = 0,      //!< the variable value is currently not defined
         DEF = 1,        //!< the variable value is defined
         IS_POINTER = 2, //!< the variable value is as a pointer
-        IS_NAN = 999    //!< the variable value is NAN
     };
 
     /**
@@ -269,12 +269,6 @@ public:
      */
     bool IsDefined() const { return GetInit() == InitType::DEF; }
 
-    /**
-     * \brief Checks if the variable is currently NAN
-     * \return InitType::NAN
-     */
-    bool IsNAN() const { return GetInit() == InitType::IS_NAN; }
-
     //@}
 
     ////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -508,27 +502,27 @@ public:
      */
     virtual void SetValString(const std::string& val);
 
-    virtual signed char GetValByte();
+    virtual signed char GetValByte() const;
 
-    virtual short GetValShort();
+    virtual short GetValShort() const;
 
-    virtual uint32_t GetValChar();
+    virtual uint32_t GetValChar() const;
 
     /**
      * \brief Get value as integer
      * \return Current value
      */
-    virtual int GetValInt();
+    virtual int GetValInt() const;
 
-    virtual long GetValLong();
+    virtual long GetValLong() const;
 
     /**
      * \brief Get value as float
      * \return Current value
      */
-    virtual float GetValFloat();
+    virtual float GetValFloat() const;
 
-    virtual double GetValDouble();
+    virtual double GetValDouble() const;
 
     /**
      * \brief Get value as string
@@ -539,7 +533,7 @@ public:
      *
      * \return Current value
      */
-    virtual std::string GetValString();
+    virtual std::string GetValString() const;
 
     /**
      * \brief Set value for pointer types
