@@ -1,6 +1,6 @@
 /*
  * This file is part of the Colobot: Gold Edition source code
- * Copyright (C) 2001-2020, Daniel Roux, EPSITEC SA & TerranovaTeam
+ * Copyright (C) 2001-2023, Daniel Roux, EPSITEC SA & TerranovaTeam
  * http://epsitec.ch; http://colobot.info; http://github.com/colobot
  *
  * This program is free software: you can redistribute it and/or modify
@@ -49,7 +49,7 @@ public:
     CBotVar* GetItem(int n, bool grow = false) override;
     CBotVar* GetItemList() override;
 
-    std::string GetValString() override;
+    std::string GetValString() const override;
 
     bool Save1State(std::ostream &ostr) override;
 
