@@ -1,6 +1,6 @@
 /*
  * This file is part of the Colobot: Gold Edition source code
- * Copyright (C) 2001-2020, Daniel Roux, EPSITEC SA & TerranovaTeam
+ * Copyright (C) 2001-2023, Daniel Roux, EPSITEC SA & TerranovaTeam
  * http://epsitec.ch; http://colobot.info; http://github.com/colobot
  *
  * This program is free software: you can redistribute it and/or modify
@@ -47,7 +47,7 @@ public:
     CBotVar* GetItem(const std::string& name) override;
     CBotVar* GetItemRef(int nIdent) override;
     CBotVar* GetItemList() override;
-    std::string GetValString() override;
+    std::string GetValString() const override;
 
     void SetPointer(CBotVar* p) override;
     CBotVarClass* GetPointer() override;
