@@ -1,6 +1,6 @@
 /*
  * This file is part of the Colobot: Gold Edition source code
- * Copyright (C) 2001-2020, Daniel Roux, EPSITEC SA & TerranovaTeam
+ * Copyright (C) 2001-2023, Daniel Roux, EPSITEC SA & TerranovaTeam
  * http://epsitec.ch; http://colobot.info; http://github.com/colobot
  *
  * This program is free software: you can redistribute it and/or modify
@@ -133,7 +133,7 @@ bool rfdestruct (CBotVar* pThis, CBotVar* pVar, CBotVar* pResult, int& Exception
     if (!pVar->IsDefined()) return true; // file not opened
     g_files.erase(pVar->GetValInt());
 
-    pVar->SetInit(CBotVar::InitType::IS_NAN);
+    pVar->SetInit(CBotVar::InitType::UNDEF);
     return true;
 }
 
@@ -203,7 +203,7 @@ bool rfclose (CBotVar* pThis, CBotVar* pVar, CBotVar* pResult, int& Exception, v
 
     g_files.erase(handleIter);
 
-    pVar->SetInit(CBotVar::InitType::IS_NAN);
+    pVar->SetInit(CBotVar::InitType::UNDEF);
     return true;
 }
 
