@@ -1,6 +1,6 @@
 /*
  * This file is part of the Colobot: Gold Edition source code
- * Copyright (C) 2001-2020, Daniel Roux, EPSITEC SA & TerranovaTeam
+ * Copyright (C) 2001-2023, Daniel Roux, EPSITEC SA & TerranovaTeam
  * http://epsitec.ch; http://colobot.info; http://github.com/colobot
  *
  * This program is free software: you can redistribute it and/or modify
@@ -37,8 +37,6 @@
 
 #include "common/system/system.h"
 
-#include "common/thread/thread.h"
-
 #include "graphics/core/nulldevice.h"
 
 #include "graphics/opengl/glutil.h"
@@ -58,9 +56,14 @@
 #include <SDL_image.h>
 
 #include <stdlib.h>
-#include <libintl.h>
 #include <getopt.h>
 #include <localename.h>
+#include <thread>
+
+#include <libintl.h>
+
+using TimeUtils::TimeStamp;
+using TimeUtils::TimeUnit;
 
 char CApplication::m_languageLocale[] = { 0 };
 
@@ -71,7 +74,6 @@ const int JOYSTICK_TIMER_INTERVAL = 1000/30;
 //! Function called by the timer
 Uint32 JoystickTimerCallback(Uint32 interval, void *);
 
-
 /**
  * \struct ApplicationPrivate
  * \brief Private data of CApplication class
@@ -138,13 +140,6 @@ CApplication::CApplication(CSystemUtils* systemUtils)
     m_absTime = 0.0f;
     m_relTime = 0.0f;
 
-    m_baseTimeStamp = m_systemUtils->CreateTimeStamp();
-    m_curTimeStamp = m_systemUtils->CreateTimeStamp();
-    m_lastTimeStamp = m_systemUtils->CreateTimeStamp();
-
-    m_manualFrameLast = m_systemUtils->CreateTimeStamp();
-    m_manualFrameTime = m_systemUtils->CreateTimeStamp();
-
 
     m_joystickEnabled = false;
 
@@ -162,13 +157,6 @@ CApplication::CApplication(CSystemUtils* systemUtils)
 
 CApplication::~CApplication()
 {
-    m_systemUtils->DestroyTimeStamp(m_baseTimeStamp);
-    m_systemUtils->DestroyTimeStamp(m_curTimeStamp);
-    m_systemUtils->DestroyTimeStamp(m_lastTimeStamp);
-
-    m_systemUtils->DestroyTimeStamp(m_manualFrameLast);
-    m_systemUtils->DestroyTimeStamp(m_manualFrameTime);
-
     m_joystickEnabled = false;
 
     m_controller.reset();
@@ -259,6 +247,7 @@ ParseArgsStatus CApplication::ParseArguments(int argc, char *argv[])
         OPT_DEBUG,
         OPT_RUNSCENE,
         OPT_SCENETEST,
+        OPT_LOADSAVE,
         OPT_LOGLEVEL,
         OPT_LANGDIR,
         OPT_DATADIR,
@@ -277,6 +266,7 @@ ParseArgsStatus CApplication::ParseArguments(int argc, char *argv[])
         { "debug", required_argument, nullptr, OPT_DEBUG },
         { "runscene", required_argument, nullptr, OPT_RUNSCENE },
         { "scenetest", no_argument, nullptr, OPT_SCENETEST },
+        { "loadsave", required_argument, nullptr, OPT_LOADSAVE },
         { "loglevel", required_argument, nullptr, OPT_LOGLEVEL },
         { "langdir", required_argument, nullptr, OPT_LANGDIR },
         { "datadir", required_argument, nullptr, OPT_DATADIR },
@@ -322,6 +312,7 @@ ParseArgsStatus CApplication::ParseArguments(int argc, char *argv[])
                 GetLogger()->Message("  -debug modes        enable debug modes (more info printed in logs; see code for reference of modes)\n");
                 GetLogger()->Message("  -runscene sceneNNN  run given scene on start\n");
                 GetLogger()->Message("  -scenetest          win every mission right after it's loaded\n");
+                GetLogger()->Message("  -loadsave path      load given saved game on start (path is <player>/<save>\n");
                 GetLogger()->Message("  -loglevel level     set log level to level (one of: trace, debug, info, warn, error, none)\n");
                 GetLogger()->Message("  -langdir path       set custom language directory path\n");
                 GetLogger()->Message("                      environment variable: COLOBOT_LANG_DIR\n");
@@ -379,6 +370,22 @@ ParseArgsStatus CApplication::ParseArguments(int argc, char *argv[])
                 m_sceneTest = true;
                 break;
             }
+            case OPT_LOADSAVE:
+            {
+                std::string playerAndPath = optarg;
+                size_t pos = playerAndPath.find_first_of("/");
+                if (pos != std::string::npos && pos > 0 && pos+1 < playerAndPath.length()) // Split player name from path
+                {
+                    m_loadSavePlayerName = playerAndPath.substr(0, pos);
+                    m_loadSaveDirName = playerAndPath.substr(pos+1, playerAndPath.length()-pos-1);
+                }
+                else
+                {
+                    GetLogger()->Error("Invalid path: '%s'\n", optarg);
+                    return PARSE_ARGS_FAIL;
+                }
+                break;
+            }
             case OPT_LOGLEVEL:
             {
                 LogLevel logLevel;
@@ -606,7 +613,7 @@ bool CApplication::Create()
                 h = atoi(hs.c_str());
             }
 
-            // Why not just set m_deviceConfig.size to w,h? Because this way if the resolution is no longer supported (e.g. changimg monitor) defaults will be used instead
+            // Why not just set m_deviceConfig.size to w,h? Because this way if the resolution is no longer supported (e.g. changing monitor) defaults will be used instead
             for (auto it = modes.begin(); it != modes.end(); ++it)
             {
                 if (it->x == w && it->y == h)
@@ -675,7 +682,7 @@ bool CApplication::Create()
         {
             GetLogger()->Error("Unknown graphics device: %s\n", graphics.c_str());
             GetLogger()->Info("Changing to default device\n");
-            m_systemUtils->SystemDialog(SDT_ERROR, "Graphics initialization error", "You have selected invalid graphics device with -graphics switch. Game will use default OpenGL device instead.");
+            m_systemUtils->SystemDialog(SystemDialogType::ERROR_MSG, "Graphics initialization error", "You have selected invalid graphics device with -graphics switch. Game will use default OpenGL device instead.");
             m_device = Gfx::CreateDevice(m_deviceConfig, "opengl");
         }
     }
@@ -711,8 +718,15 @@ bool CApplication::Create()
 
     StartLoadingMusic();
 
-    if (m_runSceneCategory == LevelCategory::Max)
+    if (!m_loadSaveDirName.empty())
+    {
+        m_controller->GetRobotMain()->SelectPlayer(m_loadSavePlayerName);
+        m_controller->GetRobotMain()->LoadSaveFromDirName(m_loadSaveDirName);
+    }
+    else if (m_runSceneCategory == LevelCategory::Max)
+    {
         m_controller->StartApp();
+    }
     else
     {
         m_controller->GetRobotMain()->UpdateCustomLevelList(); // To load the userlevels
@@ -1052,15 +1066,15 @@ int CApplication::Run()
 {
     m_active = true;
 
-    m_systemUtils->GetCurrentTimeStamp(m_baseTimeStamp);
-    m_systemUtils->GetCurrentTimeStamp(m_lastTimeStamp);
-    m_systemUtils->GetCurrentTimeStamp(m_curTimeStamp);
+    m_baseTimeStamp = m_systemUtils->GetCurrentTimeStamp();
+    m_lastTimeStamp = m_systemUtils->GetCurrentTimeStamp();
+    m_curTimeStamp = m_systemUtils->GetCurrentTimeStamp();
 
     MoveMouse(Math::Point(0.5f, 0.5f)); // center mouse on start
 
-    SystemTimeStamp *previousTimeStamp = m_systemUtils->CreateTimeStamp();
-    SystemTimeStamp *currentTimeStamp = m_systemUtils->CreateTimeStamp();
-    SystemTimeStamp *interpolatedTimeStamp = m_systemUtils->CreateTimeStamp();
+    TimeStamp previousTimeStamp{};
+    TimeStamp currentTimeStamp{};
+    TimeStamp interpolatedTimeStamp{};
 
     while (true)
     {
@@ -1164,11 +1178,11 @@ int CApplication::Run()
             // If game speed is increased then we do extra ticks per loop iteration to improve physics accuracy.
             int numTickSlices = static_cast<int>(GetSimulationSpeed());
             if(numTickSlices < 1) numTickSlices = 1;
-            m_systemUtils->CopyTimeStamp(previousTimeStamp, m_curTimeStamp);
-            m_systemUtils->GetCurrentTimeStamp(currentTimeStamp);
+            previousTimeStamp = m_curTimeStamp;
+            currentTimeStamp = m_systemUtils->GetCurrentTimeStamp();
             for(int tickSlice = 0; tickSlice < numTickSlices; tickSlice++)
             {
-                m_systemUtils->InterpolateTimeStamp(interpolatedTimeStamp, previousTimeStamp, currentTimeStamp, (tickSlice+1)/static_cast<float>(numTickSlices));
+                interpolatedTimeStamp = TimeUtils::Lerp(previousTimeStamp, currentTimeStamp, (tickSlice+1)/static_cast<float>(numTickSlices));
                 Event event = CreateUpdateEvent(interpolatedTimeStamp);
                 if (event.type != EVENT_NULL && m_controller != nullptr)
                 {
@@ -1199,9 +1213,6 @@ int CApplication::Run()
     }
 
 end:
-    m_systemUtils->DestroyTimeStamp(previousTimeStamp);
-    m_systemUtils->DestroyTimeStamp(currentTimeStamp);
-    m_systemUtils->DestroyTimeStamp(interpolatedTimeStamp);
 
     return m_exitCode;
 }
@@ -1441,7 +1452,7 @@ Event CApplication::CreateVirtualEvent(const Event& sourceEvent)
     if ((sourceEvent.type == EVENT_KEY_DOWN) || (sourceEvent.type == EVENT_KEY_UP))
     {
         auto sourceData = sourceEvent.GetData<KeyEventData>();
-        auto virtualKey = GetVirtualKey(sourceData->key);
+        auto virtualKey = GetVirtualKey(sourceData->key, sourceEvent.kmodState);
 
         if (virtualKey == sourceData->key)
         {
@@ -1495,13 +1506,13 @@ void CApplication::Render()
 
 void CApplication::RenderIfNeeded(int updateRate)
 {
-    m_systemUtils->GetCurrentTimeStamp(m_manualFrameTime);
-    long long diff = m_systemUtils->TimeStampExactDiff(m_manualFrameLast, m_manualFrameTime);
+    m_manualFrameTime = m_systemUtils->GetCurrentTimeStamp();
+    long long diff = TimeUtils::ExactDiff(m_manualFrameLast, m_manualFrameTime);
     if (diff < 1e9f / updateRate)
     {
         return;
     }
-    m_systemUtils->CopyTimeStamp(m_manualFrameLast, m_manualFrameTime);
+    m_manualFrameLast = m_manualFrameTime;
 
     Render();
 }
@@ -1529,30 +1540,26 @@ void CApplication::ResetTimeAfterLoading()
 
 void CApplication::InternalResumeSimulation()
 {
-    m_systemUtils->GetCurrentTimeStamp(m_baseTimeStamp);
-    m_systemUtils->CopyTimeStamp(m_curTimeStamp, m_baseTimeStamp);
+    m_baseTimeStamp = m_systemUtils->GetCurrentTimeStamp();
+    m_curTimeStamp = m_baseTimeStamp;
     m_realAbsTimeBase = m_realAbsTime;
     m_absTimeBase = m_exactAbsTime;
 }
 
 void CApplication::StartLoadingMusic()
 {
-    CThread musicLoadThread([this]()
+    std::thread{[this]()
     {
         GetLogger()->Debug("Cache sounds...\n");
-        SystemTimeStamp* musicLoadStart = m_systemUtils->CreateTimeStamp();
-        m_systemUtils->GetCurrentTimeStamp(musicLoadStart);
+        TimeStamp musicLoadStart{m_systemUtils->GetCurrentTimeStamp()};
 
         m_sound->Reset();
         m_sound->CacheAll();
 
-        SystemTimeStamp* musicLoadEnd = m_systemUtils->CreateTimeStamp();
-        m_systemUtils->GetCurrentTimeStamp(musicLoadEnd);
-        float musicLoadTime = m_systemUtils->TimeStampDiff(musicLoadStart, musicLoadEnd, STU_MSEC);
+        TimeStamp musicLoadEnd{m_systemUtils->GetCurrentTimeStamp()};
+        float musicLoadTime = TimeUtils::Diff(musicLoadStart, musicLoadEnd, TimeUnit::MILLISECONDS);
         GetLogger()->Debug("Sound loading took %.2f ms\n", musicLoadTime);
-    },
-    "Sound loading thread");
-    musicLoadThread.Start();
+    }}.detach();
 }
 
 bool CApplication::GetSimulationSuspended() const
@@ -1564,24 +1571,24 @@ void CApplication::SetSimulationSpeed(float speed)
 {
     m_simulationSpeed = speed;
 
-    m_systemUtils->CopyTimeStamp(m_baseTimeStamp, m_curTimeStamp);
+    m_baseTimeStamp = m_curTimeStamp;
     m_realAbsTimeBase = m_realAbsTime;
     m_absTimeBase = m_exactAbsTime;
 
     GetLogger()->Info("Simulation speed = %.2f\n", speed);
 }
 
-Event CApplication::CreateUpdateEvent(SystemTimeStamp *newTimeStamp)
+Event CApplication::CreateUpdateEvent(TimeStamp newTimeStamp)
 {
     if (m_simulationSuspended)
         return Event(EVENT_NULL);
 
-    m_systemUtils->CopyTimeStamp(m_lastTimeStamp, m_curTimeStamp);
-    m_systemUtils->CopyTimeStamp(m_curTimeStamp, newTimeStamp);
+    m_lastTimeStamp = m_curTimeStamp;
+    m_curTimeStamp = newTimeStamp;
 
-    long long absDiff = m_systemUtils->TimeStampExactDiff(m_baseTimeStamp, m_curTimeStamp);
+    long long absDiff = TimeUtils::ExactDiff(m_baseTimeStamp, m_curTimeStamp);
     long long newRealAbsTime = m_realAbsTimeBase + absDiff;
-    long long newRealRelTime = m_systemUtils->TimeStampExactDiff(m_lastTimeStamp, m_curTimeStamp);
+    long long newRealRelTime = TimeUtils::ExactDiff(m_lastTimeStamp, m_curTimeStamp);
 
     if (newRealAbsTime < m_realAbsTime || newRealRelTime < 0)
     {
@@ -1886,7 +1893,7 @@ void CApplication::SetLanguage(Language language)
             }
             else
             {
-                GetLogger()->Warn("Enviromnent locale ('%s') is not supported, setting default language\n", envLang);
+                GetLogger()->Warn("Environment locale ('%s') is not supported, setting default language\n", envLang);
                 m_language = LANGUAGE_ENGLISH;
             }
         }
@@ -1955,7 +1962,7 @@ void CApplication::SetLanguage(Language language)
     }
     catch (...)
     {
-        GetLogger()->Warn("Failed to update locale, possibly incorect system configuration. Will fallback to classic locale.\n");
+        GetLogger()->Warn("Failed to update locale, possibly incorrect system configuration. Will fallback to classic locale.\n");
         try
         {
             std::locale::global(std::locale::classic());
