@@ -1,6 +1,6 @@
 /*
  * This file is part of the Colobot: Gold Edition source code
- * Copyright (C) 2001-2020, Daniel Roux, EPSITEC SA & TerranovaTeam
+ * Copyright (C) 2001-2023, Daniel Roux, EPSITEC SA & TerranovaTeam
  * http://epsitec.ch; http://colobot.info; http://github.com/colobot
  *
  * This program is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 
 #include "common/key.h"
 
-unsigned int GetVirtualKey(unsigned int key)
+unsigned int GetVirtualKey(unsigned int key, unsigned int kmodState)
 {
     if(key == KEY(LCTRL) || key == KEY(RCTRL))
         return VIRTUAL_KMOD(CTRL);
@@ -33,5 +33,26 @@ unsigned int GetVirtualKey(unsigned int key)
     if(key == KEY(KP_ENTER))
         return KEY(RETURN);
 
+    // Remap keypad navigation keys as a workaround for the SDL issue: https://github.com/libsdl-org/SDL/issues/1766
+    if ((kmodState & KEY_MOD(NUM)) == 0)
+    {
+        if(key == KEY(KP_7))
+            return KEY(HOME);
+        if(key == KEY(KP_1))
+            return KEY(END);
+        if(key == KEY(KP_9))
+            return KEY(PAGEUP);
+        if(key == KEY(KP_3))
+            return KEY(PAGEDOWN);
+        if(key == KEY(KP_4))
+            return KEY(LEFT);
+        if(key == KEY(KP_6))
+            return KEY(RIGHT);
+        if(key == KEY(KP_8))
+            return KEY(UP);
+        if(key == KEY(KP_2))
+            return KEY(DOWN);
+    }
+
     return key;
 }
