@@ -1,6 +1,6 @@
 /*
  * This file is part of the Colobot: Gold Edition source code
- * Copyright (C) 2001-2020, Daniel Roux, EPSITEC SA & TerranovaTeam
+ * Copyright (C) 2001-2023, Daniel Roux, EPSITEC SA & TerranovaTeam
  * http://epsitec.ch; http://colobot.info; http://github.com/colobot
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,15 +24,8 @@
 
 #include "common/system/system.h"
 
-#include <sys/time.h>
-
 //@colobot-lint-exclude UndefinedFunctionRule
 
-struct SystemTimeStamp
-{
-    timespec clockTime = {0, 0};
-};
-
 class CSystemUtilsLinux : public CSystemUtils
 {
 public:
@@ -40,10 +33,6 @@ public:
 
     SystemDialogResult SystemDialog(SystemDialogType type, const std::string& title, const std::string& message) override;
 
-    void InterpolateTimeStamp(SystemTimeStamp *dst, SystemTimeStamp *a, SystemTimeStamp *b, float i) override;
-    void GetCurrentTimeStamp(SystemTimeStamp *stamp) override;
-    long long TimeStampExactDiff(SystemTimeStamp *before, SystemTimeStamp *after) override;
-
     std::string GetSaveDir() override;
 
     std::string GetEnvVar(const std::string& name) override;
@@ -51,8 +40,6 @@ public:
     bool OpenPath(const std::string& path) override;
     bool OpenWebsite(const std::string& url) override;
 
-    void Usleep(int usec) override;
-
 private:
     bool m_zenityAvailable = false;
 };
