@@ -86,7 +86,7 @@ bool CPyro::Create(PyroType type, CObject* obj, float force)
     m_engine->GetObjectBBox(objRank, min, max);
     Math::Vector pos = obj->GetPosition();
 
-    DisplayError(type, obj);  // displays eventual messages
+    if (!obj->GetProxyActivate()) DisplayError(type, obj);  // displays eventual messages
 
     for (const auto& crashSphere : obj->GetAllCrashSpheres())
     {
@@ -1579,7 +1579,7 @@ void CPyro::ExploStart()
         m_camera->SetType(CAM_TYPE_EXPLO);
         m_main->DeselectAll();
     }
-    m_main->RemoveFromSelectionHistory(m_object);
+    m_main->CutObjectLink(m_object);
 
     for (int i = 0; i < OBJECTMAXPART; i++)
     {
@@ -1652,7 +1652,7 @@ void CPyro::BurnStart()
         m_camera->SetType(CAM_TYPE_EXPLO);
         m_main->DeselectAll();
     }
-    m_main->RemoveFromSelectionHistory(m_object);
+    m_main->CutObjectLink(m_object);
 
     for (int i = 0; i < OBJECTMAXPART; i++)
     {
